import { mountAdminPortalSSO, mountAdminPortalOrgSettings, mountAdminPortalMemberManagement, mountAdminPortalSCIM } from '@stytch/vanilla-js/b2b/adminPortal';
export { AdminPortalB2BProducts } from '@stytch/vanilla-js/b2b/adminPortal';
import React, { useRef } from 'react';
import { u as useIsMounted__INTERNAL, a as useStytchB2BClient } from '../StytchB2BContext-4afdf6a8.js';
import { n as noProviderError } from '../StytchSSRProxy-34c789b5.js';
import { i as invariant, a as useIsomorphicLayoutEffect } from '../useIsomorphicLayoutEffect-681e2138.js';

const makeAdminPortalComponent = (mountFn, componentName) => {
    const Component = (props) => {
        invariant(useIsMounted__INTERNAL(), noProviderError(`<${componentName} />`, 'StytchB2BProvider'));
        const stytchClient = useStytchB2BClient();
        const containerEl = useRef(null);
        useIsomorphicLayoutEffect(() => {
            if (!containerEl.current) {
                return;
            }
            mountFn(Object.assign(Object.assign({}, props), { client: stytchClient, element: containerEl.current }));
        }, [stytchClient, props]);
        return React.createElement("div", { ref: containerEl });
    };
    return Component;
};

/**
 * The Admin Portal SSO UI component.
 * This component must be rendered within a {@link StytchB2BProvider}.
 *
 * See the {@link https://stytch.com/docs/b2b/sdks/javascript-sdk online reference}
 */
const AdminPortalSSO = makeAdminPortalComponent(mountAdminPortalSSO, 'AdminPortalSSO');

/**
 * The Admin Portal Organization Settings UI component.
 * This component must be rendered within a {@link StytchB2BProvider}.
 *
 * See the {@link https://stytch.com/docs/b2b/sdks/javascript-sdk online reference}
 */
const AdminPortalOrgSettings = makeAdminPortalComponent(mountAdminPortalOrgSettings, 'AdminPortalOrgSettings');

/**
 * The Admin Portal member management UI component.
 * This component must be rendered within a {@link StytchB2BProvider}.
 *
 * See the {@link https://stytch.com/docs/b2b/sdks/javascript-sdk online reference}
 */
const AdminPortalMemberManagement = makeAdminPortalComponent(mountAdminPortalMemberManagement, 'AdminPortalMemberManagement');

/**
 * The Admin Portal SCIM UI component.
 * This component must be rendered within a {@link StytchB2BProvider}.
 *
 * See the {@link https://stytch.com/docs/b2b/sdks/javascript-sdk online reference}
 */
const AdminPortalSCIM = makeAdminPortalComponent(mountAdminPortalSCIM, 'AdminPortalSCIM');

export { AdminPortalMemberManagement, AdminPortalOrgSettings, AdminPortalSCIM, AdminPortalSSO };
