'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var adminPortal = require('@stytch/vanilla-js/b2b/adminPortal');
var React = require('react');
var StytchB2BContext = require('../StytchB2BContext-f7acf57f.js');
var StytchSSRProxy = require('../StytchSSRProxy-86bc42b3.js');
var useIsomorphicLayoutEffect = require('../useIsomorphicLayoutEffect-672e4b66.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

const makeAdminPortalComponent = (mountFn, componentName) => {
    const Component = (props) => {
        useIsomorphicLayoutEffect.invariant(StytchB2BContext.useIsMounted__INTERNAL(), StytchSSRProxy.noProviderError(`<${componentName} />`, 'StytchB2BProvider'));
        const stytchClient = StytchB2BContext.useStytchB2BClient();
        const containerEl = React.useRef(null);
        useIsomorphicLayoutEffect.useIsomorphicLayoutEffect(() => {
            if (!containerEl.current) {
                return;
            }
            mountFn(Object.assign(Object.assign({}, props), { client: stytchClient, element: containerEl.current }));
        }, [stytchClient, props]);
        return React__default["default"].createElement("div", { ref: containerEl });
    };
    return Component;
};

/**
 * The Admin Portal SSO UI component.
 * This component must be rendered within a {@link StytchB2BProvider}.
 *
 * See the {@link https://stytch.com/docs/b2b/sdks/javascript-sdk online reference}
 */
const AdminPortalSSO = makeAdminPortalComponent(adminPortal.mountAdminPortalSSO, 'AdminPortalSSO');

/**
 * The Admin Portal Organization Settings UI component.
 * This component must be rendered within a {@link StytchB2BProvider}.
 *
 * See the {@link https://stytch.com/docs/b2b/sdks/javascript-sdk online reference}
 */
const AdminPortalOrgSettings = makeAdminPortalComponent(adminPortal.mountAdminPortalOrgSettings, 'AdminPortalOrgSettings');

/**
 * The Admin Portal member management UI component.
 * This component must be rendered within a {@link StytchB2BProvider}.
 *
 * See the {@link https://stytch.com/docs/b2b/sdks/javascript-sdk online reference}
 */
const AdminPortalMemberManagement = makeAdminPortalComponent(adminPortal.mountAdminPortalMemberManagement, 'AdminPortalMemberManagement');

/**
 * The Admin Portal SCIM UI component.
 * This component must be rendered within a {@link StytchB2BProvider}.
 *
 * See the {@link https://stytch.com/docs/b2b/sdks/javascript-sdk online reference}
 */
const AdminPortalSCIM = makeAdminPortalComponent(adminPortal.mountAdminPortalSCIM, 'AdminPortalSCIM');

Object.defineProperty(exports, 'AdminPortalB2BProducts', {
  enumerable: true,
  get: function () { return adminPortal.AdminPortalB2BProducts; }
});
exports.AdminPortalMemberManagement = AdminPortalMemberManagement;
exports.AdminPortalOrgSettings = AdminPortalOrgSettings;
exports.AdminPortalSCIM = AdminPortalSCIM;
exports.AdminPortalSSO = AdminPortalSSO;
