import { StytchB2BHeadlessClient } from '@stytch/vanilla-js/b2b/headless';
import { c as createStytchSSRProxy } from '../StytchSSRProxy-34c789b5.js';

/**
 * Creates a Headless Stytch client object to call the stytch B2B APIs.
 * The Stytch client is not available serverside.
 * @example
 * const stytch = createStytchB2BHeadlessClient('public-token-<find yours in the stytch dashboard>')
 *
 * return (
 *   <StytchB2BProvider stytch={stytch}>
 *     <App />
 *   </StytchB2BProvider>
 * )
 * @returns A {@link StytchB2BHeadlessClient}
 */
const createStytchB2BHeadlessClient = (...args) => {
    if (typeof window === 'undefined') {
        return createStytchSSRProxy();
    }
    return new StytchB2BHeadlessClient(...args);
};

export { createStytchB2BHeadlessClient };
