'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var headless = require('@stytch/vanilla-js/b2b/headless');
var StytchSSRProxy = require('../StytchSSRProxy-86bc42b3.js');

/**
 * Creates a Headless Stytch client object to call the stytch B2B APIs.
 * The Stytch client is not available serverside.
 * @example
 * const stytch = createStytchB2BHeadlessClient('public-token-<find yours in the stytch dashboard>')
 *
 * return (
 *   <StytchB2BProvider stytch={stytch}>
 *     <App />
 *   </StytchB2BProvider>
 * )
 * @returns A {@link StytchB2BHeadlessClient}
 */
const createStytchB2BHeadlessClient = (...args) => {
    if (typeof window === 'undefined') {
        return StytchSSRProxy.createStytchSSRProxy();
    }
    return new headless.StytchB2BHeadlessClient(...args);
};

exports.createStytchB2BHeadlessClient = createStytchB2BHeadlessClient;
