import { StytchB2BUIClient } from '@stytch/vanilla-js/b2b';
import { c as createStytchSSRProxy } from '../StytchSSRProxy-34c789b5.js';

/**
 * Creates a Stytch UI client object to call the Stytch APIs and render Stytch UI components.
 * The Stytch client is not available serverside.
 * If you do not use Stytch UI components, use {@link createStytchB2BHeadlessClient} to reduce your bundle size.
 * @example
 * const stytch = createStytchB2BUIClient('public-token-<find yours in the stytch dashboard>')
 *
 * return (
 *   <StytchB2BProvider stytch={stytch}>
 *     <App />
 *   </StytchB2BProvider>
 * )
 * @returns A {@link StytchB2BUIClient}
 */
const createStytchB2BUIClient = (...args) => {
    if (typeof window === 'undefined') {
        return createStytchSSRProxy();
    }
    return new StytchB2BUIClient(...args);
};

export { createStytchB2BUIClient };
