import { StytchUIClient } from '@stytch/vanilla-js';
import { c as createStytchSSRProxy } from './StytchSSRProxy-34c789b5.js';

/**
 * Creates a Stytch UI client object to call the Stytch APIs and render Stytch UI components.
 * The Stytch client is not available serverside.
 * If you do not use Stytch UI components, use {@link createStytchHeadlessClient} to reduce your bundle size.
 * @example
 * const stytch = createStytchUIClient('public-token-<find yours in the stytch dashboard>')
 *
 * return (
 *   <StytchProvider stytch={stytch}>
 *     <App />
 *   </StytchProvider>
 * )
 * @returns A {@link StytchUIClient}
 */
const createStytchUIClient = (...args) => {
    if (typeof window === 'undefined') {
        return createStytchSSRProxy();
    }
    return new StytchUIClient(...args);
};

export { createStytchUIClient };
