'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vanillaJs = require('@stytch/vanilla-js');
var StytchSSRProxy = require('./StytchSSRProxy-86bc42b3.js');

/**
 * Creates a Stytch UI client object to call the Stytch APIs and render Stytch UI components.
 * The Stytch client is not available serverside.
 * If you do not use Stytch UI components, use {@link createStytchHeadlessClient} to reduce your bundle size.
 * @example
 * const stytch = createStytchUIClient('public-token-<find yours in the stytch dashboard>')
 *
 * return (
 *   <StytchProvider stytch={stytch}>
 *     <App />
 *   </StytchProvider>
 * )
 * @returns A {@link StytchUIClient}
 */
const createStytchUIClient = (...args) => {
    if (typeof window === 'undefined') {
        return StytchSSRProxy.createStytchSSRProxy();
    }
    return new vanillaJs.StytchUIClient(...args);
};

exports.createStytchUIClient = createStytchUIClient;
